@@ -1,4 +1,3 @@
-#!/usr/bin/env python
 #-*- coding:utf-8 -*-
 
 ###############################################################
@@ -13,6 +12,8 @@
 #
 ###############################################################
 
+#pylint: disable=wrong-import-position
+
 import unittest
 import sys
 import os
@@ -171,7 +172,8 @@ class StringParameterTest(unittest.TestCase):
     """String Parameter Test"""
 
     def setUp(self):
-        self.parameter = clam.common.parameters.StringParameter('test','test','test',paramflag='-t',maxlength=10)
+        validator = lambda x: x != "blah"
+        self.parameter = clam.common.parameters.StringParameter('test','test','test',paramflag='-t',default="default",validator=validator, maxlength=10)
 
     def test1_sanity(self):
         """String parameter - sanity check"""
@@ -217,7 +219,19 @@ class StringParameterTest(unittest.TestCase):
         success = self.parameter.set("1234567890A")
         self.assertTrue(self.parameter.error == "Text too long, exceeding maximum of 10 characters allowed")
         self.assertFalse(success)
-        self.assertFalse(self.parameter.hasvalue)
+
+    def test6_default(self):
+        """String parameter - default value"""
+        self.assertTrue(self.parameter.error is None, self.parameter.error)
+        self.assertTrue(self.parameter.hasvalue)
+        self.assertTrue(self.parameter.value == "default")
+
+    def test7_customvalidator(self):
+        """String parameter - Custom validator (testing for failure)"""
+        success = self.parameter.set("blah")
+        self.assertTrue(self.parameter.error is not None)
+        self.assertFalse(success)
+
 
 class ChoiceParameterTest(unittest.TestCase):
     """Choice Parameter Test"""
@@ -229,7 +243,7 @@ class ChoiceParameterTest(unittest.TestCase):
         """Choice parameter - sanity check"""
         self.assertTrue(self.parameter.id == 'test')
         self.assertTrue(self.parameter.name == self.parameter.description == 'test')
-        self.assertTrue(self.parameter.multi == False)
+        self.assertTrue(self.parameter.multi is False)
         self.assertTrue(len(self.parameter.choices) == 3)
 
     def test2_set_value(self):
@@ -257,7 +271,7 @@ class MultiChoiceParameterTest(unittest.TestCase):
         """MultiChoice parameter - sanity check"""
         self.assertTrue(self.parameter.id == 'test')
         self.assertTrue(self.parameter.name == self.parameter.description == 'test')
-        self.assertTrue(self.parameter.multi == True)
+        self.assertTrue(self.parameter.multi is True)
         self.assertTrue(len(self.parameter.choices) == 3)
 
     def test2_set_value(self):
@@ -288,7 +302,7 @@ class MultiChoiceParameterTest(unittest.TestCase):
         xml = """<ChoiceParameter id="skip" name="Skip modules" description="Are there any components you want to skip? Skipping components you do not need may speed up the process considerably." flag="--skip=" multi="true"> <choice id="t">Tokeniser</choice> <choice id="m" selected="1">Multi-Word Detector</choice> <choice id="p" selected="1">Parser</choice> <choice id="c" selected="1">Chunker / Shallow parser</choice> <choice id="n" selected="1">Named Entity Recognition</choice></ChoiceParameter>"""
         parameter = clam.common.parameters.AbstractParameter.fromxml(xml)
         self.assertTrue(isinstance(parameter, clam.common.parameters.ChoiceParameter))
-        self.assertTrue(parameter.multi == True)
+        self.assertTrue(parameter.multi is True)
         self.assertTrue(len(parameter.choices) == 5)
         self.assertTrue(isinstance(parameter.value, list))
         self.assertTrue(not 't' in parameter.value)
@@ -314,7 +328,7 @@ class ParameterProcessingTest(unittest.TestCase):
         ]
         self.groups = [
             ('Main',
-                self.nogroups
+             self.nogroups
             )
         ]
         #valid settings
@@ -356,7 +370,7 @@ class ParameterProcessingTest(unittest.TestCase):
         """Parameter Processing - Value check (group)"""
         errors, parameters, _ = clam.common.data.processparameters(self.postdata, self.groups)
         self.assertFalse(errors)
-        group, parameters = parameters[0]
+        group, parameters = parameters[0] #pylint: disable=unused-variable
         self.assertTrue(parameters[0].value == self.postdata['teststring'])
         self.assertTrue(parameters[1].value == self.postdata['testchoice'])
         self.assertFalse(parameters[2].hasvalue)
@@ -365,14 +379,14 @@ class ParameterProcessingTest(unittest.TestCase):
 
     def test5_commandline(self):
         """Parameter Processing - Command line argument check"""
-        errors, parameters, commandlineargs = clam.common.data.processparameters(self.postdata, self.groups)
+        errors, parameters, commandlineargs = clam.common.data.processparameters(self.postdata, self.groups) #pylint: disable=unused-variable
         self.assertFalse(errors)
         self.assertTrue(commandlineargs == ['-s test', '-c c', '-i 4', '-b']) #order same as defined
 
     def test6_required(self):
         """Parameter Processing - Forgetting a required parameter (independent)"""
         postdata = {'teststring': 'test', 'testbool': True, 'testint': 4}
-        errors, parameters, commandlineargs = clam.common.data.processparameters(postdata, self.nogroups)
+        errors, parameters, commandlineargs = clam.common.data.processparameters(postdata, self.nogroups) #pylint: disable=unused-variable
         self.assertTrue(errors)
         self.assertTrue(parameters[1].id == 'testchoice')
         self.assertTrue(parameters[1].error)
@@ -380,7 +394,7 @@ class ParameterProcessingTest(unittest.TestCase):
     def test7_require(self):
         """Parameter Processing - Forgetting a required parameter (dependent)"""
         postdata = {'teststring': 'test',  'testint': 4,'testchoice':'c'}
-        errors, parameters, commandlineargs = clam.common.data.processparameters(postdata, self.nogroups)
+        errors, parameters, commandlineargs = clam.common.data.processparameters(postdata, self.nogroups) #pylint: disable=unused-variable
         self.assertTrue(errors)
         self.assertTrue(parameters[0].id == 'teststring')
         self.assertTrue(parameters[0].error)
@@ -388,7 +402,7 @@ class ParameterProcessingTest(unittest.TestCase):
     def test8_forbid(self):
         """Parameter Processing - Setting a forbidden parameter combination (dependent)"""
         postdata = {'teststring': 'test',  'testint': 4,'testfloat':0.5, 'testchoice':'c', 'testbool':False}
-        errors, parameters, commandlineargs = clam.common.data.processparameters(postdata, self.nogroups)
+        errors, parameters, commandlineargs = clam.common.data.processparameters(postdata, self.nogroups) #pylint: disable=unused-variable
         self.assertTrue(errors)
         self.assertTrue(parameters[2].id == 'testfloat')
         self.assertTrue(parameters[2].error)
